==> typescript_1.4.orig.tar.gz: TypeScript-1.4/tests/baselines/reference/switchBreakStatements.js <==
//// [switchBreakStatements.ts]
switch ('') {
    case 'a':
        break;
}

ONE:
switch ('') {
    case 'a':
        break ONE;
}

TWO:
THREE:
switch ('') {
    case 'a':
        break THREE;
}

FOUR:
switch ('') {
    case 'a':
        FIVE:
        switch ('') {
            case 'a':
                break FOUR;
        }
}

switch ('') {
    case 'a':
        SIX:
        switch ('') {
            case 'a':
                break SIX;
        }
}

SEVEN:
switch ('') {
    case 'a':
        switch ('') {
            case 'a':
                switch ('') {
                    case 'a':
                        break SEVEN;
                        EIGHT:
                        switch ('') {
                            case 'a':
                                var fn = function () { }
                                break EIGHT;
                        }
                }
        }
}


//// [switchBreakStatements.js]
switch ('') {
    case 'a':
        break;
}
ONE: switch ('') {
    case 'a':
        break ONE;
}
TWO: THREE: switch ('') {
    case 'a':
        break THREE;
}
FOUR: switch ('') {
    case 'a':
        FIVE: switch ('') {
            case 'a':
                break FOUR;
        }
}
switch ('') {
    case 'a':
        SIX: switch ('') {
            case 'a':
                break SIX;
        }
}
SEVEN: switch ('') {
    case 'a':
        switch ('') {
            case 'a':
                switch ('') {
                    case 'a':
                        break SEVEN;
                        EIGHT: switch ('') {
                            case 'a':
                                var fn = function () {
                                };
                                break EIGHT;
                        }
                }
        }
}

==> typescript_1.8.10.orig.tar.gz: TypeScript-1.8.10/tests/baselines/reference/switchBreakStatements.js <==
//// [switchBreakStatements.ts]

switch ('') {
    case 'a':
        break;
}

ONE:
switch ('') {
    case 'a':
        break ONE;
}

TWO:
THREE:
switch ('') {
    case 'a':
        break THREE;
}

FOUR:
switch ('') {
    case 'a':
        FIVE:
        switch ('') {
            case 'a':
                break FOUR;
        }
}

switch ('') {
    case 'a':
        SIX:
        switch ('') {
            case 'a':
                break SIX;
        }
}

SEVEN:
switch ('') {
    case 'a':
        switch ('') {
            case 'a':
                switch ('') {
                    case 'a':
                        break SEVEN;
                        EIGHT:
                        switch ('') {
                            case 'a':
                                var fn = function () { }
                                break EIGHT;
                        }
                }
        }
}


//// [switchBreakStatements.js]
switch ('') {
    case 'a':
        break;
}
ONE: switch ('') {
    case 'a':
        break ONE;
}
TWO: THREE: switch ('') {
    case 'a':
        break THREE;
}
FOUR: switch ('') {
    case 'a':
        FIVE: switch ('') {
            case 'a':
                break FOUR;
        }
}
switch ('') {
    case 'a':
        SIX: switch ('') {
            case 'a':
                break SIX;
        }
}
SEVEN: switch ('') {
    case 'a':
        switch ('') {
            case 'a':
                switch ('') {
                    case 'a':
                        break SEVEN;
                        EIGHT: switch ('') {
                            case 'a':
                                var fn = function () { };
                                break EIGHT;
                        }
                }
        }
}
